pub type Ptr<A> = Rc<A>;Expand description
A pointer type for use in TeX - this is just an alias for Rc, but may by replaced by Arc in the future.
Aliased Type
struct Ptr<A> { /* private fields */ }pub type Ptr<A> = Rc<A>;A pointer type for use in TeX - this is just an alias for Rc, but may by replaced by Arc in the future.
struct Ptr<A> { /* private fields */ }